@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/sbin/perl
 #
 # by Sergei Butakov <sergei@bslos.com> (2011-05-1x - 2011-05-2x for V3.2.1)
 #
@@ -179,7 +179,6 @@ $Lang{BackupPC_Summary} = <<EOF;
     <td align="center">Последнее действие</td></tr>
 \$strGood
 </table>
-<br><br>
 \${h2("Узлы, не имеющие резервные копии")}
 <p>
 Всего \$hostCntNone узлов, не имеющих резервных копий.
@@ -376,7 +375,6 @@ $Lang{BackupPC__Queue_Summary} = "BackupPC: Queue Summary";
 # --------------------------------
 $Lang{Backup_Queue_Summary} = <<EOF;
 \${h1("Сводка по Очередям")}
-<br><br>
 \${h2("Очередь Пользовательских Задач")}
 <p>
 Следующие запросы находятся в очереди:
@@ -387,7 +385,6 @@ $Lang{Backup_Queue_Summary} = <<EOF;
     <td> Пользователь </td></tr>
 \$strUser
 </table>
-<br><br>
 
 \${h2("Очередь Фоновых Задач")}
 <p>
@@ -399,7 +396,6 @@ $Lang{Backup_Queue_Summary} = <<EOF;
     <td> Пользователь </td></tr>
 \$strBg
 </table>
-<br><br>
 \${h2("Очередь Команд")}
 <p>
 Следующие команды находятся в очереди:
@@ -696,9 +692,7 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 
 \$restoreStr
 </p>
-<br><br>
 \${h2("Сводка Ошибок при Копировании")}
-<br><br>
 <table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> № </td>
     <td align="center"> Тип </td>
@@ -710,7 +704,6 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 </tr>
 \$errStr
 </table>
-<br><br>
 
 \${h2("Сводка по Файлам")}
 <p>
@@ -738,7 +731,6 @@ Empty files and SMB errors aren\'t counted in the reuse and new counts.
 </tr>
 \$sizeStr
 </table>
-<br><br>
 
 \${h2("Сводка по Сжатию")}
 <p>
@@ -761,7 +753,6 @@ Empty files and SMB errors aren\'t counted in the reuse and new counts.
 </tr>
 \$compStr
 </table>
-<br><br>
 EOF
 
 $Lang{Host__host_Archive_Summary} = "BackupPC: Host \$host Archive Summary";
@@ -901,7 +892,7 @@ $Lang{DirHistory_for__host} = <<EOF;
 <li> Щёлкните по версии файла (\$Lang->{DirHistory_fileLink}0,
      \$Lang->{DirHistory_fileLink}1, ...) для загрузки этого файла;
 <li> Файлы из разных резервных копий, содержащие одно и то же,
-     имеют один и тот же номер версии;
+     имеют один и тот же номер версии (PleaseTranslateThis: except between v3 and v4 backups);
 <li> Файлы и каталоги, отсутствующие в конкретной копии, показаны
      пустым прямоугольником;
 <li> Файлы одной версии могут отличаться разными атрибутами файловой системы.
