@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/sbin/perl
 
 # By Serhiy Yakimchuck yakim@yakim.org.ua 02 sept 2012 vor version 3.2.1
 #
@@ -178,7 +178,6 @@ $Lang{BackupPC_Summary} = <<EOF;
     <td align="center"> Остання дія </td></tr>
 \$strGood
 </table>
-<br><br>
 \${h2("Хости без резервних копій")}
 <p>
 Загалом \$hostCntNone хостів без резервних копій.
@@ -375,7 +374,6 @@ $Lang{BackupPC__Queue_Summary} = "BackupPC: Зведена інформація
 # --------------------------------
 $Lang{Backup_Queue_Summary} = <<EOF;
 \${h1("Зведена інформація по чергам завдань")}
-<br><br>
 \${h2("Черга завдань користувачів")}
 <p>
 Наступні запити користувачів поставлені до черги:
@@ -386,7 +384,6 @@ $Lang{Backup_Queue_Summary} = <<EOF;
     <td> Користувач </td></tr>
 \$strUser
 </table>
-<br><br>
 
 \${h2("Зведена інформація по фоновій черзі")}
 <p>
@@ -398,7 +395,6 @@ $Lang{Backup_Queue_Summary} = <<EOF;
     <td> Користувач </td></tr>
 \$strBg
 </table>
-<br><br>
 \${h2("Зведена інформація по черзі команд")}
 <p>
 Наступні команди були поставлені до черги:
@@ -695,9 +691,7 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 
 \$restoreStr
 </p>
-<br><br>
 \${h2("Зведена інформація про помилки Xfer")}
-<br><br>
 <table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Backup# </td>
     <td align="center"> Тип </td>
@@ -709,7 +703,6 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 </tr>
 \$errStr
 </table>
-<br><br>
 
 \${h2("Зведена інформація по файлах")}
 <p>
@@ -736,7 +729,6 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 </tr>
 \$sizeStr
 </table>
-<br><br>
 
 \${h2("Зведена інформація про стискання")}
 <p>
@@ -759,7 +751,6 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 </tr>
 \$compStr
 </table>
-<br><br>
 EOF
 
 $Lang{Host__host_Archive_Summary} = "BackupPC: Host \$host Archive Summary";
@@ -899,7 +890,7 @@ $Lang{DirHistory_for__host} = <<EOF;
 <li> Натисніть на посилання на версію файла (\$Lang->{DirHistory_fileLink}0,
      \$Lang->{DirHistory_fileLink}1, ...) для його звантаженняe,
 <li> Фали з однаковим вмістом мають однакову версію в усіх
-      резервних копіях,
+      резервних копіях (PleaseTranslateThis: except between v3 and v4 backups),
 <li> Файли та теки, що відсутні в поточній резервній копії позначені 
      порожнім прямокутником.
 <li> Файли однієї версії можуть відрізнятися атрибутами файлової системи.
